@@ -1,11 +1,11 @@
-from src.cameras.multicam_manager import CVCameraManager
+from src.cameras.multicam_manager.cv_camera_manager import OpenCVCameraManager
 from src.core_processor.mediapipe_skeleton_detection.mediapipe_skeleton_detection import (
     MediapipeSkeletonDetection,
 )
 
 
 class MediapipeSkeletonDetectionService:
-    def __init__(self, cam_manager: CVCameraManager):
+    def __init__(self, cam_manager: OpenCVCameraManager):
         self._cam_manager = cam_manager
 
     def run(self, model_complexity: int):
